#
# BTZen - library to asynchronously access Bluetooth devices.
#
# Copyright (C) 2015-2022 by Artur Wroblewski <wrobell@riseup.net>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

class BTZenError(Exception):
    """
    Base, abstract BTZen exception.
    """

class CallError(BTZenError):
    """
    Error when starting an asynchronous call is not possible.
    """

class ConnectionError(BTZenError):
    """
    Connection error.
    """

class ConfigurationError(BTZenError):
    """
    Device configuration error.
    """

class DataReadError(BTZenError):
    """
    Device data reading error.
    """

class DataWriteError(BTZenError):
    """
    Device data wrte error.
    """

# vim: sw=4:et:ai
